@@ -77,7 +77,7 @@ class Network:
     @classmethod
     def devnet(cls):
         return cls(
-            lcd_endpoint='devnet.injective.dev:10337',
+            lcd_endpoint='https://devnet.lcd.injective.dev',
             grpc_endpoint='devnet.injective.dev:9900',
             grpc_exchange_endpoint='devnet.injective.dev:9910',
             chain_id='injective-777',
@@ -92,7 +92,7 @@ class Network:
             raise ValueError("Must be one of {}".format(nodes))
 
         return cls(
-            lcd_endpoint=f"{node}.injective.dev:10337",
+            lcd_endpoint="https://testnet.lcd.injective.dev",
             grpc_endpoint=f"{node}.injective.dev:9900",
             grpc_exchange_endpoint=f"{node}.injective.dev:9910",
             chain_id='injective-888',
@@ -113,7 +113,6 @@ class Network:
             raise ValueError("Must be one of {}".format(nodes))
 
         return cls(
-                #lcd_endpoint=f"{node}.injective.network:10337",
             lcd_endpoint="https://lcd.injective.network",
             grpc_endpoint=f"{node}.injective.network:9900",
             grpc_exchange_endpoint=f"{node}.injective.network:9910",
